moduleName = "demo"
parDict = {}

# moduleName = "buildClr"
# parDict = {}

# moduleName = "assetbundle"
# parDict = {}

# moduleName = "apk"
# parDict = {}
